{% extends 'generic/object_list.html' %}
{% load buttons %}
{% load i18n %}
{% load helpers %}
{% load django_tables2 %}
{% load render_table from django_tables2 %}
{% block title %}
  Slurp'it log
{% endblock %}

{% block header %}
  <div class="title-container px-3 pb-3">

    {# Title #}
    
    <div id="content-title">
      {% include "slurpit_netbox/logo.html" %}
      {# Center-align title in object-edit views #}
      <h1 class="h2 w-100">Logging</h1>
      {% block subtitle %}{% endblock %}
    </div>

    <div class="controls">
      <div class="control-group">
        <a type="submit" class="btn btn-danger btn-sm" href="?clear=true">
          <i class="mdi mdi-trash-can-outline" aria-hidden="true"></i> Clear all logging
        </a>
      </div>
    </div>

  </div>
{% endblock header %}


<footer class="footer container-fluid">
    {% block footer %}
      <div class="row align-items-center justify-content-between mx-0">
  
        <div class="col-sm-12 col-md-auto fs-4 noprint">
          <nav class="nav justify-content-center justify-content-lg-start">
            {% block footer_links %}
              <a type="button" class="nav-link h6" href="https://slurpit.io" target="_blank">
                https://slurpit.io
              </a>
            {% endblock footer_links %}
          </nav>
        </div>
  
        <div class="col-sm-12 col-md-auto text-center text-lg-end text-muted"  >
          <span class="d-block d-md-inline">{% annotated_now %} {% now 'T' %}</span>
          <span class="ms-md-3 d-block d-md-inline">{{ settings.HOSTNAME }} (v{{ settings.VERSION }})</span>
          <span class="ms-md-3 d-block d-md-inline">Slurpit(v{{ settings.PLUGINS_CONFIG.slurpit_netbox.version }})</span>
        </div>
  
      </div>
    {% endblock footer %}
  </footer>


