{% load buttons %}
{% load i18n %}
<div class="show {% if request.GET.tab == 'onboarded' %}active{% endif %}" id="onboarded-device-list" role="tabpanel" aria-labelledby="onboarded-device-list-tab">

     {# "Select all" form #}
     {% if table.paginator.num_pages > 1 %}
       <div id="select-all-box" class="d-none card noprint">
         <div class="form col-md-12">
           <div class="card-body">
             <div class="float-end">
               {% if 'bulk_edit' in actions %}
                 {% bulk_edit_button model query_params=request.GET %}
               {% endif %}
               {% if 'bulk_delete' in actions %}
                 {% bulk_delete_button model query_params=request.GET %}
               {% endif %}
             </div>
             <div class="form-check">
               <input type="checkbox" id="select-all" name="_all" class="form-check-input" />
               <label for="select-all" class="form-check-label">
                 {% blocktrans trimmed with count=table.rows|length object_type_plural=table.data.verbose_name_plural %}
                   Select <strong>all {{ count }} {{ object_type_plural }}</strong> matching query
                 {% endblocktrans %}
               </label>
             </div>
           </div>
         </div>
       </div>
     {% endif %}
     <div class="form form-horizontal">
       <div class="card">
         <div class="card-body htmx-container table-responsive" id="object_list">
           {% include 'htmx/table.html' %}
         </div>
       </div>
     </div>
 </div>