# Generated by Django 4.2.8 on 2024-01-27 22:07

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('slurpit_netbox', '0002_alter_slurpitplanning_name_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='slurpitimporteddevice',
            name='ipv4',
            field=models.CharField(max_length=23, null=True),
        ),
        migrations.AlterField(
            model_name='slurpitstageddevice',
            name='ipv4',
            field=models.CharField(max_length=23, null=True),
        ),
    ]
